#ifndef __MISC_H__
#define __MISC_H__
/*
char * shorter_string(const char *long_string);
char *remove_extention_and_basepath(const char *filename);
*/
gchar * format_time(unsigned long seconds);

#endif
